@@ -2,7 +2,7 @@ import logging
 
 from fileFormatter import FileFormatter
 from cmdParser import CmdParser
-# import log
+import log
 
 
 logger = logging.getLogger('Formatter')
@@ -14,10 +14,6 @@ def run():
     FileFormatter(CmdParser.parse_arguments()).run()
 
 
-# run()
-
-# PositionConfig('default.editorconfig')
-
 logger.debug(f'program finished')
 
 #
