@@ -11,8 +11,12 @@ class RubyCodeParser:
         self.type_of_file = '.rb'
         self.list_name_defs_without_exclamation_mark = []
 
-        self.list_signs = ('=', '==', '!=', '<', '<=', '>', '>=')
+        self.list_signs = ('=', '==', '!=', '<', '<=', '>', '>=', '+')
         self.list_unnecessary_pref_in_question_def = ('is', 'does', 'can')
+        self.list_other_parameter = ('+', '-', '*', '/', '**', '==', '>', '<', '|', '&', '^', 'eql?', 'equal?')
+        self.list_item_parameter = ('<<', '[]', '===')
+
+        self.list_of_classes_name = []
 
     ############
 
@@ -23,13 +27,14 @@ class RubyCodeParser:
         self.list_of_lines = self._check_def_in_file()
         self.list_of_lines = self._check_name_of_class()
         self.list_of_lines = self._check_variables_in_def_annotation()
+        self.list_of_lines = self._check_other_parameter()
+        self.list_of_lines = self._check_variables_in_file_cross_road()
+        self.list_of_lines = self._check_foreign_class_method()
+        self.list_of_lines = self._check_import_class()
 
         self.list_of_lines = self._check_comments()
         self.list_of_lines = self._check_comment_annotations()
 
-        # for l in self.list_of_lines:
-        #     print(l)
-
         final_str = RubyCodeParser._convert_list_to_string(org_list=self.list_of_lines)
         return final_str
 
@@ -58,6 +63,9 @@ class RubyCodeParser:
                 if 'def' in words:
                     new_list_of_lines.append(line)
                     continue
+                if '.' in words:
+                    new_list_of_lines.append(line)
+                    continue
 
                 # print(f'line ---> {line}, words --> {words}')
                 word = self._find_name_of_variable_in_words(words)
@@ -83,6 +91,78 @@ class RubyCodeParser:
 
         return new_list_of_lines
 
+    def _check_variables_in_file_cross_road(self):
+        new_list_of_lines = []
+
+        for i in range(len(self.list_of_lines)):
+
+            line = self._get_line_by_index(i)
+
+            if line != '':
+
+                words = self._get_words_in_line(line)
+
+                if 'def' in words or 'class' in words or '#' in words:
+                    new_list_of_lines.append(line)
+                    continue
+
+                # print(f'line ---> {line}, words --> {words}')
+
+                for j in range(1, len(words)):
+                    if words[j] == '':
+                        continue
+
+                    # print(f'word --> |{words[j]}|', end=' ')
+
+                    if words[j].isnumeric():
+                        # print('\n')
+                        continue
+                    if words[j] in self.list_signs:
+                        # print('\n')
+                        continue
+                    if words[j] in self.list_item_parameter:
+                        # print('\n')
+                        continue
+                    if words[j] in self.list_other_parameter:
+                        # print('\n')
+                        continue
+                    if '"' in words[j]:
+                        # print('\n')
+                        continue
+                    if "'" in words[j]:
+                        # print('\n')
+                        continue
+                    if "(" in words[j]:
+                        # print('\n')
+                        continue
+                    if "#" in words[j]:
+                        # print('\n')
+                        continue
+                    if "." in words[j]:
+                        # print('\n')
+                        continue
+                    if "=" in words[j]:
+                        # print('\n')
+                        continue
+                    if RubyCodeParser._is_const(words[j]):
+                        continue
+
+                    # print(f' can be var')
+
+                    new_word = self._check_snake_case_format(words[j], isFile=False, isExclamationMark=False,
+                                                             isQuestionMark=False, isScreaming_case=False)
+
+                    if ',' in words[j]:
+                        new_word += ','
+
+                    line = RubyCodeParser._change_word_in_line(line, words[j], new_word)
+
+                new_list_of_lines.append(line)
+            else:
+                new_list_of_lines.append(line)
+
+        return new_list_of_lines
+
     def _check_def_in_file(self):
         new_list_of_lines = []
         self._load_all_names_of_def_without_exclamation_mark()
@@ -197,7 +277,7 @@ class RubyCodeParser:
                         first_part = RubyCodeParser._find_word_def_spaces_before(words)
                         # print(f'first_part = {first_part}')
 
-                        was_scopes = RubyCodeParser._was_scope_in_mane_of_def(words)
+                        was_scopes = RubyCodeParser._was_scope_in_name_of_def(words)
 
                         new_line = RubyCodeParser._create_new_line_with_def_annotation(first_part=first_part,
                                                                                        second_part=list_variables_in_annotation,
@@ -219,10 +299,84 @@ class RubyCodeParser:
 
         return new_list_of_lines
 
+    def _check_other_parameter(self):
+
+        new_list_of_lines = []
+
+        need_word_other = False
+        need_word_item = False
+
+        list_variables_in_annotation = []
+
+        for i in range(len(self.list_of_lines)):
+            line = self._get_line_by_index(i)
+
+            if line != '':
+                words = RubyCodeParser._get_words_in_line(line)
+
+                name_of_def = RubyCodeParser._find_name_of_def_in_words(words)
+
+                if name_of_def != '':
+
+                    tmp_list_variables_in_annotation = RubyCodeParser._get_variables_in_def_annotation(words)
+
+                    # print(f'find [line] with def --> {words}')
+                    # print(f'find line with [def] --> {name_of_def}')
+                    # print(f'find vars in def annotation --> {tmp_list_variables_in_annotation}')
+
+                    if name_of_def in self.list_other_parameter:
+                        # print(f'find parameter --> {name_of_def} and we should use word other')
+
+                        if tmp_list_variables_in_annotation[0] != 'other':
+                            tmp_list_variables_in_annotation[0] = 'other'
+                            need_word_other = True
+
+                    elif name_of_def in self.list_item_parameter:
+                        # print(f'find parameter --> {name_of_def} and we should use word item')
+
+                        if tmp_list_variables_in_annotation[0] != 'item':
+                            tmp_list_variables_in_annotation[0] = 'item'
+                            need_word_item = True
+
+                    else:
+                        new_list_of_lines.append(line)
+                        continue
+
+                    first_part = RubyCodeParser._find_word_def_spaces_before(words)
+
+                    new_line = first_part + ' ' + name_of_def + '(' + tmp_list_variables_in_annotation[0] + ')'
+                    # print(f'old line |{line}|')
+                    # print(f'new line |{new_line}|')
+                    new_list_of_lines.append(new_line)
+
+                else:
+
+                    if need_word_other:
+                        need_word_other = False
+                        # print(f'need to change word item to other in line: {line}')
+                        logger.debug(f'need to change word item to other')
+                        line = RubyCodeParser._change_word_in_line(line=line, old_word='item', new_word='other')
+
+                    if need_word_item:
+                        need_word_item = False
+                        # print(f'need to change word other to item in line: {line}')
+                        logger.debug(f'need to change word other to item')
+                        line = RubyCodeParser._change_word_in_line(line=line, old_word='other', new_word='item')
+
+                    new_list_of_lines.append(line)
+
+            else:
+                new_list_of_lines.append(line)
+
+        return new_list_of_lines
+
     def _check_name_of_class(self):
 
         new_list_of_lines = []
 
+        find_first_class = False
+        find_one_more_class_in_file = False
+
         for i in range(len(self.list_of_lines)):
 
             line = self._get_line_by_index(i)
@@ -237,6 +391,7 @@ class RubyCodeParser:
                         name_of_class = names_of_classes[j]
 
                         if name_of_class != '':
+
                             new_name_of_class = self._check_camel_case_format(name_of_folder=name_of_class)
                             new_name_of_class = RubyCodeParser._check_acronyms_format(name_of_folder=new_name_of_class)
 
@@ -247,8 +402,25 @@ class RubyCodeParser:
                             else:
                                 logger.debug(f'name {name_of_class} is ok')
 
+                            self.list_of_classes_name.append(name_of_class)
+
                     tmp = RubyCodeParser._get_words_in_line(line)
 
+                    if not find_first_class:
+                        find_first_class = True
+                    else:
+                        if not find_one_more_class_in_file:
+                            find_one_more_class_in_file = True
+
+                    if find_one_more_class_in_file:
+                        suitable_file_name = self._check_snake_case_format(name_of_folder=tmp[1],
+                                                                           isQuestionMark=False, isFile=False,
+                                                                           isExclamationMark=False,
+                                                                           isScreaming_case=False)
+
+                        logger.debug(
+                            f'You should replace {tmp[1]} class to new file, suitable name will be {suitable_file_name}{self.type_of_file} ')
+
                     for j in range(len(tmp)):
                         if tmp[j] == '':
                             tmp[j] = '<'
@@ -259,6 +431,283 @@ class RubyCodeParser:
 
         return new_list_of_lines
 
+    def _check_foreign_class_method(self):
+
+        def _get_words_by_point(word):
+            words_chars = RubyCodeParser._get_chars_from_str(word)
+
+            # print(f'chars: {words_chars}')
+
+            find_point = False
+
+            first_word = ''
+            second_word = ''
+
+            for i in range(len(words_chars)):
+
+                if words_chars[i] == '.':
+                    find_point = True
+                    continue
+
+                if not find_point:
+                    first_word += words_chars[i]
+
+                if find_point:
+                    if words_chars[i] == '(':
+                        break
+                    second_word += words_chars[i]
+
+            # print(f'first_word = |{first_word}|, second_word = |{second_word}|')
+
+            return [first_word, second_word]
+
+        def _get_part_in_scope(word):
+            word_chars = RubyCodeParser._get_chars_from_str(word)
+
+            i = 0
+            scope = ''
+
+            find_scope = False
+
+            for i in range(len(word_chars)):
+                if word_chars[i] == '(':
+                    scope += word_chars[i]
+                    find_scope = True
+                    continue
+
+                if find_scope:
+                    if word_chars[i] == ')':
+                        scope += word_chars[i]
+                        return scope
+                    scope += word_chars[i]
+
+            return scope
+
+        def _get_vars_with_value_in_scope(scope):
+            list_of_variables = []
+
+            part_with_annotation = RubyCodeParser._convert_list_to_string(scope, seperator=' ')
+
+            chars = RubyCodeParser._get_chars_from_str(scope)
+
+            # print(f'chars = {chars}')
+
+            if '(' not in chars:
+                return list_of_variables
+
+            i = 0
+
+            for i in range(len(chars)):
+                if chars[i] == '(':
+                    break
+
+            i += 1
+
+            if chars[i] == ')':
+                return list_of_variables
+
+            # print(f'chars[i] = {chars[i]}')
+
+            tmp = ''
+
+            while i <= (len(chars) - 1):
+                if chars[i] == ',' or chars[i] == ')':
+                    list_of_variables.append(tmp)
+                    tmp = ''
+                    i += 1
+                    continue
+
+                if chars[i] != ' ':
+                    tmp += chars[i]
+                i += 1
+
+            return list_of_variables
+
+        def _fixing_vars_in_scope(vars):
+
+            list_vars_in_scope = []
+
+            for i in range(len(vars)):
+
+                vars_chars = RubyCodeParser._get_chars_from_str(vars[i])
+
+                var = ''
+                value_with_rovno = ''
+
+                find_rovno = False
+
+                # for j in range(len(vars_chars)):
+
+                j = 0
+
+                while j < len(vars_chars):
+                    if vars_chars[j] == '=':
+                        find_rovno = True
+                        break
+                    var += vars_chars[j]
+                    j += 1
+
+                if find_rovno:
+
+                    while j < len(vars_chars):
+                        value_with_rovno += vars_chars[j]
+                        j += 1
+
+
+                print(f'var = {var}')
+                var = self._check_snake_case_format(var, isScreaming_case=False, isExclamationMark=False, isQuestionMark=False, isFile=False)
+
+                print(f'value_with_rovno = {value_with_rovno}')
+
+                list_vars_in_scope.append(var + value_with_rovno)
+
+            return list_vars_in_scope
+
+
+        new_list_of_lines = []
+
+        find_foreign_class_method = False
+
+        for i in range(len(self.list_of_lines)):
+
+            line = self._get_line_by_index(i)
+            # print(f'line = {line}')
+            line_chars = RubyCodeParser._get_chars_from_str(line)
+            # print(f'line_chars = {line_chars}')
+
+            if line == '':
+                new_list_of_lines.append(line)
+                continue
+
+            words = self._get_words_in_line(line)
+
+            if 'def' in words:
+                new_list_of_lines.append(line)
+                continue
+
+            if 'class' in words:
+                new_list_of_lines.append(line)
+                continue
+
+            for j in range(len(words)):
+
+                if '.' in words[j] and '=' in words:
+                    find_foreign_class_method = True
+                    logger.debug(f'{line_chars} can be name of class with method')
+
+                    name_of_class = _get_words_by_point(word=words[j])[0]
+                    name_of_method = _get_words_by_point(word=words[j])[1]
+                    scope = _get_part_in_scope(line_chars)
+                    scope = _get_vars_with_value_in_scope(scope)
+
+                    # print(f'[before fixing] name_of_class = |{name_of_class}|, name_of_method = |{name_of_method}|')
+
+                    fix_name_of_class = self._check_camel_case_format(name_of_class)
+                    fix_name_of_method = self._check_snake_case_format(name_of_method, isScreaming_case=False,
+                                                                       isExclamationMark=False, isQuestionMark=False,
+                                                                       isFile=False)
+
+                    # print(f'fix_name_of_class = |{fix_name_of_class}|, fix_name_of_method = |{fix_name_of_method}|')
+                    # print(f'part in scope --> {scope}')
+
+                    scope = _fixing_vars_in_scope(scope)
+                    # print(f'[fixing]part in scope --> {scope}')
+
+                    tmp_list = words[0:j]
+                    start_line = RubyCodeParser._convert_list_to_string(tmp_list, seperator=' ')
+
+                    new_line = start_line + ' ' + fix_name_of_class + '.' + fix_name_of_method + '(' + RubyCodeParser._convert_list_to_string(scope, seperator=', ') + ')'
+
+                    # print(f'[fixing] line --> |{new_line}|')
+
+                    new_list_of_lines.append(new_line)
+
+                elif '.' in words[j] and not '=' in words:
+                    find_foreign_class_method = True
+                    logger.debug(f'{words[j]} can be object of class with method')
+
+                    name_of_object = _get_words_by_point(word=words[j])[0]
+                    name_of_method = _get_words_by_point(word=words[j])[1]
+                    scope = _get_part_in_scope(words[j])
+                    scope = _get_vars_with_value_in_scope(scope)
+                    scope = _fixing_vars_in_scope(scope)
+
+                    fix_name_of_object = self._check_snake_case_format(name_of_object, isScreaming_case=False,
+                                                                       isExclamationMark=False, isQuestionMark=False,
+                                                                       isFile=False)
+
+                    fix_name_of_method = self._check_snake_case_format(name_of_method, isScreaming_case=False,
+                                                                       isExclamationMark=False, isQuestionMark=False,
+                                                                       isFile=False)
+
+                    new_line = fix_name_of_object + '.' + fix_name_of_method + '(' + RubyCodeParser._convert_list_to_string(scope, seperator=', ') + ')'
+
+                    new_list_of_lines.append(new_line)
+
+            if not find_foreign_class_method:
+                new_list_of_lines.append(line)
+            else:
+                find_foreign_class_method = False
+
+        return new_list_of_lines
+
+    def _check_import_class(self):
+
+        def is_include(words):
+            if 'include' in words:
+                return True
+            else:
+                return False
+
+        def get_names_of_include(words):
+
+            def get_list_name(words):
+                return words[1:len(words)]
+
+            names = get_list_name(words)
+
+            for i in range(len(names)):
+                if ',' in names[i]:
+                    names[i] = names[i].replace(',', '')
+
+            return names
+
+        def fix_names_of_import(list_names):
+
+            for i in range(len(list_names)):
+                list_names[i] = self._check_camel_case_format(list_names[i])
+
+            return list_names
+
+        new_list_of_lines = []
+
+        for i in range(len(self.list_of_lines)):
+
+            line = self._get_line_by_index(i)
+
+            if line != '':
+                words = self._get_words_in_line(line)
+
+                if is_include(words):
+
+                    logger.debug(f'find line with include --> {line}')
+
+                    list_names_of_include = get_names_of_include(words)
+
+                    # print(f'names of include --> {list_names_of_include}')
+
+                    list_names_of_include = fix_names_of_import(list_names_of_include)
+
+                    # print(f'[fixed] names of include --> {list_names_of_include}')
+
+                    line = 'include ' + RubyCodeParser._convert_list_to_string(list_names_of_include, seperator=', ')
+
+                    # print(f'new_line --> {line}')
+
+            new_list_of_lines.append(line)
+
+        return new_list_of_lines
+
     ############
 
     def _check_snake_case_format(self, name_of_folder, isFile, isExclamationMark, isQuestionMark, isScreaming_case):
@@ -289,6 +738,9 @@ class RubyCodeParser:
             elif self.list_char_name[i] == '@':
                 recommend_new_name += self._verify_under_line(i)
 
+            elif self.list_char_name[i] == '.':
+                recommend_new_name += self._verify_under_line(i)
+
         if isFile:
             name_of_folder += self.type_of_file
             recommend_new_name += self.type_of_file
@@ -544,7 +996,7 @@ class RubyCodeParser:
         return name_of_def
 
     @staticmethod
-    def _was_scope_in_mane_of_def(words):
+    def _was_scope_in_name_of_def(words):
         for i in range(len(words)):
             if i > 0:
                 if words[i - 1] == 'def':
@@ -1099,13 +1551,13 @@ class RubyCodeParser:
         start = chars.index('#')
         end = 0
 
-        for i in range(start+1, len(chars)):
+        for i in range(start + 1, len(chars)):
             if chars[i] == ' ':
                 end += 1
                 continue
             break
 
-        del chars[start+1:end]
+        del chars[start + 1:end]
 
         chars.insert(1, ' ')
         chars.insert(1, ' ')
@@ -1165,7 +1617,8 @@ class RubyCodeParser:
                                 i = i + 1
                                 if chars[i] == 'W':
                                     i = i + 1
-                                    chars = RubyCodeParser._add_double_point_and_spaces_after_keyword(chars=chars, index=i)
+                                    chars = RubyCodeParser._add_double_point_and_spaces_after_keyword(chars=chars,
+                                                                                                      index=i)
                                     break
 
             if chars[i] == 'O':
@@ -1184,7 +1637,8 @@ class RubyCodeParser:
                                         i = i + 1
                                         if chars[i] == 'E':
                                             i = i + 1
-                                            chars = RubyCodeParser._add_double_point_and_spaces_after_keyword(chars=chars, index=i)
+                                            chars = RubyCodeParser._add_double_point_and_spaces_after_keyword(
+                                                chars=chars, index=i)
                                             break
 
         comment = RubyCodeParser._get_str_from_chars(chars)
